#!/usr/bin/env python

#
# Wiretap SDK tool for obtaining the clip format associated with a clip node.
#

from __future__ import print_function

import getopt
import sys
from libwiretapPythonClientAPI import (
    WireTapClient,
    WireTapServerHandle,
    WireTapNodeHandle,
    WireTapClipFormat
)

def printUsage():
    print("Usage:\n"
          "-n <node Id>\n"
          "[-h <hostname>]")

def main():

    # Check the command line options for correctness.
    try:
        opts, _ = getopt.getopt(sys.argv, "h:n:")
    except getopt.GetoptError:
        printUsage()
        sys.exit(2)

    # Declare variables (to be set from command line arguments).
    # For hostName, the default "localhost" will work if a Wiretap server
    # is running on your machine.
    #
    hostName = "localhost"
    nodeId = ""

    # Parse command line and set variables just declared.
    for opt, arg in opts:
        if opt == '-h':
            hostName = arg
        elif opt == '-n':
            nodeId = arg

    if nodeId == "":
        print("Node ID not specified.\n")
        printUsage()
        sys.exit(2)

    # Initialize the Wiretap Client API.
    #
    wiretapClient = WireTapClient()
    if not wiretapClient.init():
        raise Exception("Unable to initialize Wiretap client API")

    try:
        # Instantiate a server handle
        #
        server = WireTapServerHandle(hostName)

        # Instantiate the clip node from the specified ID
        # and get its clip format.
        #
        node = WireTapNodeHandle(server, nodeId)
        fmt = WireTapClipFormat()
        if not node.getClipFormat(fmt):
            raise Exception("Unable to retrieve clip format: %s" % node.lastError())

        colourSpace = fmt.colourSpace()

        # Display the clip formatting parameters stored in the clip format.
        #
        print("Format %s" % fmt.formatTag())
        print("Width %d" % fmt.width())
        print("Height %d" % fmt.height())
        print("BitsPerPixel %d" % fmt.bitsPerPixel())
        print("Channels %d" % fmt.numChannels())
        print("BufferSize %d" % fmt.frameBufferSize())
        print("PixelRatio %g" % fmt.pixelRatio())
        print("FrameRate %g" % fmt.frameRate())
        print("ScanFormat %s" % WireTapClipFormat.scanFormatStr(fmt.scanFormat()))
        if colourSpace:
            print("ColourSpace %s" % colourSpace)
        print("MetaDataTag %s" % fmt.metaDataTag())
        print("MetaDataStream %s" % fmt.metaData())

    finally:
        # Must destroy WireTapServerHandle and WireTapNodeHandle before
        # uninitializing the Wiretap Client API.
        #
        node = None
        server = None


if __name__ == '__main__':
    main()
