#!/usr/bin/env python

#
# Wiretap SDK tool for listing frame IDs and frame file paths for all
# the frames in a clip.
#

from __future__ import print_function

import getopt
import sys

from libwiretapPythonClientAPI import (
    WireTapClient,
    WireTapServerHandle,
    WireTapNodeHandle,
    WireTapInt,
    WireTapStr
)

def printUsage():
    print("Usage:\n"
          "-n <node Id>\n"
          "[-h <hostname> (default = localhost)]\n"
          "[-d <delimiter character> (default = none)]\n"
          "[-s <separator character> (default = newline)]\n"
          "[-p <print frame file paths>]")

def main():

    # Check the command line options for correctness.
    try:
        opts, _ = getopt.getopt(sys.argv, "h:n:d:s:p")
    except getopt.GetoptError:
        printUsage()
        sys.exit(2)

    # Declare variables (to be set from command line arguments).
    # For hostName, the default "localhost" will work if a Wiretap server
    # is running on your machine.
    #
    nodeId = ""
    hostName = "localhost"
    delimiter = r'\0'
    separator = r'\n'
    printPaths = 0

    # Parse command line and set variables just declared.
    #
    for opt, arg in opts:
        if opt == '-h':
            hostName = arg
        elif opt == '-n':
            nodeId = arg
        elif opt == '-p':
            printPaths = 1
        elif opt == '-d':
            delimiter = arg[0]
        elif opt == '-s':
            separator = arg[0]

    if nodeId == "":
        print("Node ID not specified.\n")
        printUsage()
        sys.exit(2)

    # Initialize the Wiretap Client API.
    #
    wiretapClient = WireTapClient()
    if not wiretapClient.init():
        raise Exception("Unable to initialize Wiretap client API")

    try:
        # Instantiate a server handle
        #
        server = WireTapServerHandle(hostName)

        # Instantiate the node and get the number of frames in the clip.
        #
        node = WireTapNodeHandle(server, nodeId)
        numFrames = WireTapInt(0)

        if not node.getNumFrames(numFrames):
            raise Exception("Unable to retrieve the number of frames: %s" % node.lastError())

        # Iterate through all frames getting their file paths and IDs.
        #
        i = 0
        frame = WireTapStr()
        while i < numFrames:

            # Get the frame path.
            #
            if printPaths:
                if not node.getFrameIdPath(i, frame):
                    raise Exception('Unable to retrieve frame path: %s ' % node.lastError())

            # Get the frame id
            #
            else:
                if not node.getFrameId(i, frame):
                    raise Exception('Unable to retrieve frame id: %s.' % node.lastError())

            # Print the node info.
            #
            if i == int(numFrames) - 1:
                sep = '\n'
            else:
                sep = separator

            if delimiter != r'\0':
                print("%c%s%c%c" % (delimiter, frame.c_str(), delimiter, sep), end="")
            else:
                print("%s%c" % (frame.c_str(), sep), end="")

            i = i + 1

    finally:
        # Must destroy WireTapServerHandle and WireTapNodeHandle before
        # uninitializing the Wiretap Client API.
        #
        node = None
        server = None

if __name__ == '__main__':
    main()
